@@ -24,12 +24,19 @@ class SegmentBodyRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'imageseg', '2019-12-30', 'SegmentBody','imageseg')
+		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
+	def get_Async(self):
+		return self.get_body_params().get('Async')
+
+	def set_Async(self,Async):
+		self.add_body_params('Async', Async)
+
 	def get_ImageURL(self):
 		return self.get_query_params().get('ImageURL')
 
